# -*- encoding: utf-8 -*-

from . import account_move
from . import ir_actions_report
